@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2016-2021 Stéphane Caron <stephane.caron@normalesup.org>
+# Copyright (C) 2016-2022 Stéphane Caron and the qpsolvers contributors.
 #
 # This file is part of qpsolvers.
 #
@@ -59,7 +59,6 @@ try:
             ]
         )
 
-
 except ImportError:
 
     def cvxopt_concatenate(G, sign: float, m: int):
@@ -97,7 +96,7 @@ def concatenate_bound(
     h : numpy.ndarray or None
         Updated linear inequality vector.
     """
-    if G is None:
+    if G is None or h is None:
         G = sign * np.eye(len(b))
         h = sign * b
     else:  # G is not None and h is not None
