@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2016-2021 Stéphane Caron <stephane.caron@normalesup.org>
+# Copyright (C) 2016-2022 Stéphane Caron and the qpsolvers contributors.
 #
 # This file is part of qpsolvers.
 #
@@ -95,9 +95,9 @@ class TestSolveLS(unittest.TestCase):
             known_solution = array([2.0 / 3, -1.0 / 3, 2.0 / 3])
             sol_tolerance = 1e-5 if solver == "ecos" else 1e-6
             ineq_tolerance = 1e-7 if solver == "scs" else 1e-9
-            self.assertTrue(norm(x - known_solution) < sol_tolerance)
-            self.assertTrue(norm(x_sp - known_solution) < sol_tolerance)
-            self.assertTrue(max(dot(G, x) - h) <= ineq_tolerance)
+            self.assertLess(norm(x - known_solution), sol_tolerance)
+            self.assertLess(norm(x_sp - known_solution), sol_tolerance)
+            self.assertLess(max(dot(G, x) - h), ineq_tolerance)
             self.assertTrue(allclose(dot(A, x), b))
 
         return test
